import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  arc,
  pie,
  scaleBand,
  scaleLinear,
  max,
} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';


const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 20,
  bottom: 20,
  left: 200,
};

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }
  console.log(data[0]);

  const innerHeight =
    height - margin.top - margin.bottom;
  const innerWidth =
    width - margin.left - margin.right;
  
  const yValue = (d) => d.Country;
  const xValue = (d) => d.Population;

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
				<AxisBottom xScale={xScale} innerHeight={innerHeight}/>
        <AxisLeft yScale={yScale} />
        <Marks data={data} xScale={xScale} yScale={yScale} xValue ={xValue} yValue ={yValue}/>

       
      </g>
    </svg>
  );
};

const rootElement = document.getElementById(
  'root'
);
ReactDOM.render(<App />, rootElement);

//   data.map((d, i) => (
//   <path
//     fill={d['RGB hex value']}
//     d={pieArc({
//       startAngle:
//         (i / data.length) * 2 * Math.PI,
//       endAngle:
//         ((i + 1) / data.length) *
//         2 *
//         Math.PI,
//     })}
//   />
// ))
